interface ResultStat {
    rowsAffected: number;
    rowsRead: number | null;
    rowsWritten: number | null;
    queryDurationMs: number | null;
}
declare enum ColumnType {
    TEXT = 1,
    INTEGER = 2,
    REAL = 3,
    BLOB = 4
}
interface ColumnHeader {
    /**
     * The key of row data that this column represents.
     */
    name: string;
    /**
     * The display name of the column. This is the name that should be used when displaying the column to the user.
     */
    displayName: string;
    /**
     * The original type of the column returned from database driver.
     */
    originalType: string | null;
    /**
     * Provide hint to the client on how to render the column.
     * If not provided, the client should infer the type from the data.
     */
    type?: ColumnType;
    /**
     * Database name or shcema name
     */
    schema?: string;
    /**
     * The actual table name
     */
    table?: string;
    /**
     * The original column name returned from database driver.
     */
    originalName?: string;
    /**
     * Indicate if this column is a primary key.
     */
    primaryKey?: boolean;
    /**
     * The column id in the table. This is useful for Postgres.
     */
    columnId?: number;
    /**
     * The table id in the database. This is useful for Postgres.
     */
    tableId?: number;
}
interface ResultSet {
    rows: Record<string, unknown>[];
    headers: ColumnHeader[];
    stat: ResultStat;
    lastInsertRowid?: number;
}
type SupportedDialect = "sqlite" | "mysql" | "postgres" | "dolt";
interface Token {
    type: string;
    value: string;
}

interface ArrayBasedTransformProps<HeaderType> {
    rows: unknown[][];
    headers: HeaderType[];
    headersMapper: (header: HeaderType, headerIdx: number) => {
        name: string;
        type?: number;
        originalType: string | null;
        schema?: string | undefined;
        table?: string | undefined;
        originalName?: string | undefined;
        primaryKey?: boolean | undefined;
        columnId?: number | undefined;
        tableId?: number | undefined;
    };
    transformValue?: (value: unknown, header: ColumnHeader) => unknown;
}
declare function transformArrayBasedResult<HeaderType>({ headers, headersMapper, rows, transformValue, }: ArrayBasedTransformProps<HeaderType>): {
    rows: Record<string, unknown>[];
    headers: ColumnHeader[];
};

declare function transformTursoResult(tursoResult: any): ResultSet;

declare function transformCloudflareD1(cloudflareResult: any): ResultSet;

declare function transformMySQLResult(mysqlResult: any): ResultSet;

declare function setPgParser(pgTypes: any): void;
declare function transformPgResult(pgResult: any): ResultSet;

interface StarbaseResult {
    columns: string[];
    rows: unknown[][];
    meta: {
        rows_read: number;
        rows_written: number;
    };
}
declare function transformStarbaseResult(data: StarbaseResult): ResultSet;

declare function tokenizeSql(sql: string, dialect: SupportedDialect): Token[];

declare function fillVariables(sql: string, variables: object, dialect: SupportedDialect): string;

declare function escapeSqlValue(value: unknown): string;

export { type ColumnHeader, ColumnType, type ResultSet, type ResultStat, type SupportedDialect, type Token, escapeSqlValue, fillVariables, setPgParser, tokenizeSql, transformArrayBasedResult, transformCloudflareD1, transformMySQLResult, transformPgResult, transformStarbaseResult, transformTursoResult };
